@@ -17,25 +17,27 @@ import os
 import sys
 import socket
 import signal
-import psycopg2
+import pg8000
 import tempfile
 import subprocess
 from glob import glob
 from time import sleep
 from shutil import copytree, rmtree
 from datetime import datetime
+from contextlib import closing
+
 
 __all__ = ['Postgresql', 'skipIfNotFound']
 
 SEARCH_PATHS = (['/usr/local/pgsql', '/usr/local'] +
                 glob('/usr/lib/postgresql/*') +  # for Debian/Ubuntu
-                glob('/opt/local/lib/postgresql-*'))  # for MacPorts
+                glob('/opt/local/lib/postgresql*'))  # for MacPorts
 DEFAULT_SETTINGS = dict(auto_start=2,
                         base_dir=None,
                         initdb=None,
                         initdb_args='-U postgres -A trust',
                         postgres=None,
-                        postgres_args='-h 127.0.0.1 -F',
+                        postgres_args='-h 127.0.0.1 -F -c logging_collector=off',
                         pid=None,
                         port=None,
                         copy_data_from=None)
@@ -84,12 +86,12 @@ class Postgresql(object):
             raise AttributeError("'Postgresql' object has no attribute '%s'" % name)
 
     def dsn(self, **kwargs):
-        # "dbname=test host=localhost user=postgres"
+        # "database=test host=localhost user=postgres"
         params = dict(kwargs)
         params.setdefault('port', self.port)
         params.setdefault('host', '127.0.0.1')
         params.setdefault('user', 'postgres')
-        params.setdefault('dbname', 'test')
+        params.setdefault('database', 'test')
 
         return params
 
@@ -97,7 +99,7 @@ class Postgresql(object):
         params = self.dsn(**kwargs)
 
         url = ('postgresql://%s@%s:%d/%s' %
-               (params['user'], params['host'], params['port'], params['dbname']))
+               (params['user'], params['host'], params['port'], params['database']))
 
         return url
 
@@ -124,9 +126,12 @@ class Postgresql(object):
                     self.initdb_args.split())
 
             try:
-                subprocess.Popen(args, stdout=subprocess.PIPE, stderr=subprocess.STDOUT).communicate()
-            except Exception as exc:
-                raise RuntimeError("failed to spawn initdb: %r" % exc)
+                p = subprocess.Popen(args, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+                output, err = p.communicate()
+                if p.returncode != 0:
+                    raise RuntimeError("initdb failed: %r" % err)
+            except OSError as exc:
+                raise RuntimeError("failed to spawn initdb: %s" % exc)
 
     def start(self):
         if self.pid:
@@ -167,17 +172,16 @@ class Postgresql(object):
                 sleep(0.1)
 
             # create test database
-            with psycopg2.connect(**self.dsn(dbname='template1')) as conn:
-                conn.set_isolation_level(psycopg2.extensions.ISOLATION_LEVEL_AUTOCOMMIT)
-                with conn.cursor() as cursor:
+            with closing(pg8000.connect(**self.dsn(database='postgres'))) as conn:
+                conn.autocommit = True
+                with closing(conn.cursor()) as cursor:
                     cursor.execute("SELECT COUNT(*) FROM pg_database WHERE datname='test'")
                     if cursor.fetchone()[0] <= 0:
                         cursor.execute('CREATE DATABASE test')
 
     def stop(self, _signal=signal.SIGINT):
-        if self._owner_pid == os.getpid():
-            self.terminate(_signal)
-            self.cleanup()
+        self.terminate(_signal)
+        self.cleanup()
 
     def terminate(self, _signal=signal.SIGINT):
         if self.pid is None:
@@ -206,6 +210,7 @@ class Postgresql(object):
 
         if self._use_tmpdir and os.path.exists(self.base_dir):
             rmtree(self.base_dir, ignore_errors=True)
+            self._use_tmpdir = False
 
     def read_log(self):
         try:
@@ -216,9 +221,9 @@ class Postgresql(object):
 
     def is_connection_available(self):
         try:
-            with psycopg2.connect(**self.dsn(dbname='template1')):
+            with closing(pg8000.connect(**self.dsn(database='template1'))):
                 pass
-        except psycopg2.OperationalError:
+        except pg8000.Error:
             return False
         else:
             return True
